<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fil">
<context>
    <name>App.About</name>
    <message>
        <location filename="../main.cpp" line="101"/>
        <location filename="../main.cpp" line="105"/>
        <source>System Monitor</source>
        <translation>Sistema ng Monitor</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="91"/>
        <source>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</source>
        <translation>Ang System Monitor ay isang tool upang monitorhin ang load ng sistema sa real-time, tingnan at kontrolin ang mga proseso at serbisyo na nangunguna sa iyong sistema.</translation>
    </message>
</context>
<context>
    <name>BaseDetailViewWidget</name>
    <message>
        <location filename="../gui/base/base_detail_view_widget.cpp" line="29"/>
        <source>Hide details</source>
        <translation>I-hide ang mga detalye</translation>
    </message>
    <message>
        <location filename="../gui/base/base_detail_view_widget.cpp" line="40"/>
        <location filename="../gui/base/base_detail_view_widget.cpp" line="52"/>
        <source>Overall utilization</source>
        <translation>Kabuuang paggamit</translation>
    </message>
    <message>
        <location filename="../gui/base/base_detail_view_widget.cpp" line="43"/>
        <location filename="../gui/base/base_detail_view_widget.cpp" line="54"/>
        <source>Individual utilization</source>
        <translation>Indibidwal na paggamit</translation>
    </message>
</context>
<context>
    <name>BlockDevItemWidget</name>
    <message>
        <location filename="../gui/block_dev_item_widget.cpp" line="154"/>
        <source>Read</source>
        <translation>Basa</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_item_widget.cpp" line="158"/>
        <source>Write</source>
        <translation>Isulat</translation>
    </message>
</context>
<context>
    <name>CPUDetailGrapTableItem</name>
    <message>
        <location filename="../gui/cpu_detail_widget.cpp" line="168"/>
        <location filename="../gui/cpu_detail_widget.cpp" line="285"/>
        <source>60 seconds</source>
        <translation>60 segundo</translation>
    </message>
</context>
<context>
    <name>CPUInfoModel</name>
    <message>
        <location filename="../model/cpu_info_model.cpp" line="49"/>
        <source>%1 days %2 hours %3 minutes</source>
        <translation>%1 araw %2 oras %3 minuto</translation>
    </message>
</context>
<context>
    <name>CPUSummaryTableModel</name>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="91"/>
        <source>Utilization</source>
        <translation>Paggamit</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="93"/>
        <source>Frequency</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="98"/>
        <source>Max frequency</source>
        <translation>Frequency</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="100"/>
        <source>Average frequency</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="104"/>
        <source>Up time</source>
        <translation>Up time</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="106"/>
        <source>Sockets</source>
        <translation>Sockets</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="110"/>
        <source>Logical processors</source>
        <translation>Logical processors</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="112"/>
        <source>Virtualization</source>
        <translation>Virtualization</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="116"/>
        <source>L1i cache</source>
        <translation>L1i cache</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="118"/>
        <source>L1d cache</source>
        <translation>L1d cache</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="122"/>
        <source>L2 cache</source>
        <translation>L2 cache</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="124"/>
        <source>L3 cache</source>
        <translation>L3 cache</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="128"/>
        <source>Load average</source>
        <translation>Kasalukuyang average ng load</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="130"/>
        <source>File descriptors</source>
        <translation>File descriptors</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="134"/>
        <source>Processes</source>
        <translation>Processes</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="136"/>
        <source>Threads</source>
        <translation>Threads</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="140"/>
        <source>Host name</source>
        <translation>Host name</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="142"/>
        <source>OS type</source>
        <translation>Uri ng OS</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="146"/>
        <source>Version</source>
        <translation>Version</translation>
    </message>
</context>
<context>
    <name>Cancel</name>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="310"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancel</translation>
    </message>
</context>
<context>
    <name>ChartViewWidget</name>
    <message>
        <location filename="../gui/chart_view_widget.cpp" line="321"/>
        <source>60 seconds</source>
        <translation>60 segundo</translation>
    </message>
</context>
<context>
    <name>Common.Search</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="493"/>
        <location filename="../gui/system_service_table_view.cpp" line="476"/>
        <source>No search results</source>
        <translation>Walang mga resulta ng paghahanap</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <location filename="../compact_cpu_monitor.cpp" line="89"/>
        <source>Details</source>
        <translation>Mga Detalye</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <location filename="../cpu_monitor.cpp" line="72"/>
        <source>Details</source>
        <translation>Mga Detalye</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Active.State</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="165"/>
        <source>active</source>
        <translation>aktibo</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="167"/>
        <source>reloading</source>
        <translation>nagloload</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="169"/>
        <source>inactive</source>
        <translation>diaktibo</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="170"/>
        <source>failed</source>
        <translation>nagkabigo</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="172"/>
        <source>activating</source>
        <translation>nag-aktibo</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="174"/>
        <source>deactivating</source>
        <translation>nag-deaktibo</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Load.State</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="146"/>
        <source>stub</source>
        <translation>stub</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="149"/>
        <source>not-found</source>
        <translation>nagkita</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="151"/>
        <source>bad-setting</source>
        <translation>mali setting</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="152"/>
        <source>error</source>
        <translation>mali</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="153"/>
        <source>merged</source>
        <translation>mga pinagsamahan</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="154"/>
        <source>masked</source>
        <translation>naka-mask</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="147"/>
        <source>loaded</source>
        <translation>nag-load</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Startup.Mode</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="297"/>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="295"/>
        <source>Auto</source>
        <translation>Awtomatiko</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="296"/>
        <source>Manual</source>
        <translation>Manwal</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.State</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="274"/>
        <source>enabled</source>
        <translation>naka-enable</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="275"/>
        <source>disabled</source>
        <translation>naka-disable</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="276"/>
        <source>static</source>
        <translation>static</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="277"/>
        <source>transient</source>
        <translation>transient</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="278"/>
        <source>indirect</source>
        <translation>indirect</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="280"/>
        <source>enabled-runtime</source>
        <translation>naka-enable sa runtime</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="281"/>
        <source>masked</source>
        <translation>naka-mask</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="283"/>
        <source>generated</source>
        <translation>nag-generated</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Sub.State</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="217"/>
        <source>dead</source>
        <translation>mga patay</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="219"/>
        <source>start-pre</source>
        <translation>pangunahing pag-start</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="221"/>
        <source>start</source>
        <translation>pangunahing pag-start</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="223"/>
        <source>start-post</source>
        <translation>pangalawang pag-start</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="225"/>
        <source>running</source>
        <translation>nag-run</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="227"/>
        <source>exited</source>
        <translation>nag-exit</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="229"/>
        <source>reload</source>
        <translation>Ibalik</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="231"/>
        <source>stop</source>
        <translation>Iwan</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="233"/>
        <source>stop-watchdog</source>
        <translation>Iwan ang watchdog</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="235"/>
        <source>stop-sigterm</source>
        <translation>Iwan ang sigterm</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="237"/>
        <source>stop-sigkill</source>
        <translation>Iwan ang sigkill</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="239"/>
        <source>stop-post</source>
        <translation>Iwan ang post</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="241"/>
        <source>final-sigterm</source>
        <translation>Final sigterm</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="243"/>
        <source>final-sigkill</source>
        <translation>Final sigkill</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="245"/>
        <source>failed</source>
        <translation>Nagkabigo</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="247"/>
        <source>auto-restart</source>
        <translation>Automatikong restart</translation>
    </message>
</context>
<context>
    <name>DBusAlarmNotify</name>
    <message>
        <location filename="../dbus/dbusalarmnotify.cpp" line="38"/>
        <location filename="../dbus/dbusalarmnotify.cpp" line="50"/>
        <source>Warning</source>
        <translation>Uwian</translation>
    </message>
    <message>
        <location filename="../dbus/dbusalarmnotify.cpp" line="39"/>
        <source>Your CPU usage is higher than %1%!</source>
        <translation>Ang iyong paggamit ng CPU ay mas mataas kaysa sa %1%!</translation>
    </message>
    <message>
        <location filename="../dbus/dbusalarmnotify.cpp" line="51"/>
        <source>Your memory usage is higher than %1%!</source>
        <translation>Ang iyong paggamit ng memorya ay mas mataas kaysa sa %1%!</translation>
    </message>
    <message>
        <location filename="../dbus/dbusalarmnotify.cpp" line="71"/>
        <source>View</source>
        <translation type="unfinished">View</translation>
    </message>
</context>
<context>
    <name>DeailTableModel</name>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="67"/>
        <source>Used</source>
        <translation>Ginamit</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="69"/>
        <source>Available</source>
        <translation>Nagagamit</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="73"/>
        <source>Shared</source>
        <translation>Ibinahagi</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="75"/>
        <source>Cached</source>
        <translation>Nakalagay</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="79"/>
        <source>Buffers</source>
        <translation>Buffers</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="81"/>
        <source>Cached swap</source>
        <translation>Nakalagay na swap</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="85"/>
        <source>Active</source>
        <translation type="unfinished">Active</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="87"/>
        <source>Inactive</source>
        <translation>Wala nang aktibo</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="91"/>
        <source>Dirty</source>
        <translation>Mapait</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="93"/>
        <source>Mapped</source>
        <translation>Nakakalat</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="97"/>
        <source>Total swap</source>
        <translation>Kabug-osang swap</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="99"/>
        <source>Free swap</source>
        <translation>Libreng swap</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="103"/>
        <source>Slab</source>
        <translation>Slab</translation>
    </message>
</context>
<context>
    <name>DeailTableModelBlock</name>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="70"/>
        <source>Model</source>
        <translation>Modelo</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="72"/>
        <source>Read speed</source>
        <translation>Layo ng bilis</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="76"/>
        <source>Write speed</source>
        <translation>Bilis ng pagsulat</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="78"/>
        <source>Capacity</source>
        <translation>Kapasidad</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="82"/>
        <source>Sectors read</source>
        <translation>Sectors na binasa</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="84"/>
        <source>Reads/s</source>
        <translation>Basa/s</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="88"/>
        <source>Sectors read/s</source>
        <translation>Sektors na basa/s</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="90"/>
        <source>Reads merged/s</source>
        <translation>Basa na mits合并/s</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="94"/>
        <source>Sectors written</source>
        <translation>Sektors na isulat</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="96"/>
        <source>Writes completed </source>
        <translation>Isulat na tapos </translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="100"/>
        <source>Writes merged</source>
        <translation>Isulat na mits合并</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="102"/>
        <source>Writes/s</source>
        <translation>Isulat/s</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="106"/>
        <source>Sectors written/s</source>
        <translation>Sektors na isulat/s</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="108"/>
        <source>Writes merged/s</source>
        <translation>Isulat na mits合并/s</translation>
    </message>
</context>
<context>
    <name>Error.Dialog</name>
    <message>
        <location filename="../gui/dialog/error_dialog.cpp" line="73"/>
        <source>OK</source>
        <comment>button</comment>
        <translation type="unfinished">OK</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <location filename="../common/common.cpp" line="32"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="38"/>
        <source>Display shortcuts</source>
        <translation>Ipakita ang mga shortcut</translation>
    </message>
</context>
<context>
    <name>Kill.Process.Dialog</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="173"/>
        <source>Ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Pagtatapos ng proseso ay maaaring magresulta sa pagkawala ng data.
Sigurado ka bang nais mong magpatuloy?</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="530"/>
        <location filename="../gui/process_table_view.cpp" line="172"/>
        <location filename="../gui/process_table_view.cpp" line="379"/>
        <source>End process</source>
        <translation>Tapos ang proseso</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="380"/>
        <source>Force ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Pagtatapos ng proseso ay maaaring magresulta sa pagkawala ng data.
Sigurado ka bang nais mong magpatuloy?</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="531"/>
        <source>Force ending this application may cause data loss.
Are you sure you want to continue?</source>
        <translation>Pagtatapos ng aplikasyon ay maaaring magresulta sa pagkawala ng data.
Sigurado ka bang nais mong magpatuloy?</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="539"/>
        <location filename="../gui/process_table_view.cpp" line="179"/>
        <location filename="../gui/process_table_view.cpp" line="387"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished">Cancel</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="540"/>
        <location filename="../gui/process_table_view.cpp" line="388"/>
        <source>Force End</source>
        <comment>button</comment>
        <translation type="unfinished">Force End</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="180"/>
        <source>End</source>
        <comment>button</comment>
        <translation type="unfinished">End</translation>
    </message>
</context>
<context>
    <name>Logout</name>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="311"/>
        <source>Logout</source>
        <translation>Ilog out</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../gui/main_window.cpp" line="181"/>
        <source>Settings</source>
        <translation>Mga setting</translation>
    </message>
</context>
<context>
    <name>MemStatViewWidget</name>
    <message>
        <location filename="../gui/mem_stat_view_widget.cpp" line="52"/>
        <source>Size</source>
        <translation>Laki</translation>
    </message>
</context>
<context>
    <name>NetInfoDetailItemDelegate</name>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="157"/>
        <location filename="../gui/netif_summary_view_widget.h" line="159"/>
        <source>IP address:</source>
        <translation>Alamat ng IP:</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="157"/>
        <source>Netmask:</source>
        <translation>Netmask:</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="157"/>
        <source>Broadcast:</source>
        <translation>Broadcast:</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="159"/>
        <source>Prefixlen:</source>
        <translation>Prefixlen:</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="159"/>
        <source>Scope:</source>
        <translation>Scope:</translation>
    </message>
</context>
<context>
    <name>NetInfoModel</name>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="293"/>
        <source>Connection type</source>
        <translation>Uri ng koneksyon</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="301"/>
        <source>ESSID</source>
        <translation>ESSID</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="307"/>
        <source>Link quality</source>
        <translation>Kalidad ng link</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="312"/>
        <source>Signal strength</source>
        <translation>Kahusayan ng signal</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="317"/>
        <source>Noise level</source>
        <translation>Antas ng noise</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="323"/>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="328"/>
        <source>Bandwidth</source>
        <translation>Bandwidth</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="333"/>
        <source>RX packets</source>
        <translation>RX packets</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="338"/>
        <source>RX bytes</source>
        <translation>RX bytes</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="343"/>
        <source>RX errors</source>
        <translation>RX errors</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="348"/>
        <source>RX dropped</source>
        <translation>RX dropped</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="353"/>
        <source>RX overruns</source>
        <translation>RX overruns</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="358"/>
        <source>RX frame</source>
        <translation>RX frame</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="363"/>
        <source>TX packets</source>
        <translation>TX packets</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="368"/>
        <source>TX bytes</source>
        <translation>TX bytes</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="373"/>
        <source>TX errors</source>
        <translation>TX errors</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="383"/>
        <source>TX overruns</source>
        <translation>TX overruns</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="388"/>
        <source>TX carrier</source>
        <translation>TX carrier</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="267"/>
        <location filename="../gui/netif_summary_view_widget.h" line="269"/>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="282"/>
        <location filename="../gui/netif_summary_view_widget.h" line="284"/>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="378"/>
        <source>TX dropped</source>
        <translation>TX dropped</translation>
    </message>
</context>
<context>
    <name>Process.Attributes.Dialog</name>
    <message>
        <location filename="../gui/process_attribute_dialog.cpp" line="143"/>
        <source>Command line</source>
        <translation>Command line</translation>
    </message>
    <message>
        <location filename="../gui/process_attribute_dialog.cpp" line="148"/>
        <source>Start time</source>
        <translation>Start time</translation>
    </message>
    <message>
        <location filename="../gui/process_attribute_dialog.cpp" line="138"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
</context>
<context>
    <name>Process.Choose.Window.Dialog</name>
    <message>
        <location filename="../gui/xwin_kill_preview_background_widget.cpp" line="152"/>
        <source>Click the application you want to end</source>
        <translation>Click the application you want to end</translation>
    </message>
</context>
<context>
    <name>Process.Graph.Title</name>
    <message>
        <location filename="../gui/detail_view_stacked_widget.cpp" line="183"/>
        <location filename="../gui/mem_detail_view_widget.cpp" line="25"/>
        <location filename="../gui/mem_stat_view_widget.cpp" line="107"/>
        <location filename="../memory_monitor.cpp" line="177"/>
        <source>Memory</source>
        <translation>Memory</translation>
    </message>
    <message>
        <location filename="../gui/netif_item_view_widget.cpp" line="95"/>
        <location filename="../gui/netif_item_view_widget.cpp" line="121"/>
        <source>Receive</source>
        <translation>Receive</translation>
    </message>
</context>
<context>
    <name>Process.Graph.View</name>
    <message>
        <location filename="../compact_cpu_monitor.cpp" line="233"/>
        <location filename="../cpu_monitor.cpp" line="233"/>
        <location filename="../cpu_monitor.cpp" line="242"/>
        <location filename="../gui/cpu_detail_widget.cpp" line="371"/>
        <location filename="../gui/detail_view_stacked_widget.cpp" line="182"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../compact_disk_monitor.cpp" line="153"/>
        <source>Disk read</source>
        <translation>Disk read</translation>
    </message>
    <message>
        <location filename="../compact_disk_monitor.cpp" line="154"/>
        <source>Disk write</source>
        <translation>Disk write</translation>
    </message>
    <message>
        <location filename="../compact_memory_monitor.cpp" line="191"/>
        <location filename="../memory_monitor.cpp" line="203"/>
        <source>Memory</source>
        <translation>Memory</translation>
    </message>
    <message>
        <location filename="../compact_memory_monitor.cpp" line="203"/>
        <location filename="../compact_memory_monitor.cpp" line="210"/>
        <location filename="../gui/mem_stat_view_widget.cpp" line="115"/>
        <location filename="../memory_monitor.cpp" line="214"/>
        <location filename="../memory_monitor.cpp" line="221"/>
        <source>Swap</source>
        <translation>Swap</translation>
    </message>
    <message>
        <location filename="../compact_memory_monitor.cpp" line="204"/>
        <location filename="../memory_monitor.cpp" line="215"/>
        <source>Not enabled</source>
        <translation>Not enabled</translation>
    </message>
    <message>
        <location filename="../compact_network_monitor.cpp" line="158"/>
        <location filename="../network_monitor.cpp" line="216"/>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <location filename="../compact_network_monitor.cpp" line="163"/>
        <location filename="../network_monitor.cpp" line="221"/>
        <source>Upload</source>
        <translation>Upload</translation>
    </message>
    <message>
        <location filename="../gui/detail_view_stacked_widget.cpp" line="184"/>
        <location filename="../gui/netif_detail_view_widget.cpp" line="28"/>
        <location filename="../network_monitor.cpp" line="198"/>
        <source>Network</source>
        <translation>Network</translation>
    </message>
    <message>
        <location filename="../compact_network_monitor.cpp" line="160"/>
        <location filename="../network_monitor.cpp" line="218"/>
        <source>Total Received</source>
        <translation>Total Received</translation>
    </message>
    <message>
        <location filename="../compact_network_monitor.cpp" line="165"/>
        <location filename="../network_monitor.cpp" line="223"/>
        <source>Total Sent</source>
        <translation>Kabugtang Natapos</translation>
    </message>
    <message>
        <location filename="../gui/netif_item_view_widget.cpp" line="104"/>
        <location filename="../gui/netif_item_view_widget.cpp" line="130"/>
        <source>Send</source>
        <translation>Ipadala</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_detail_view_widget.cpp" line="21"/>
        <location filename="../gui/detail_view_stacked_widget.cpp" line="185"/>
        <source>Disks</source>
        <translation>Disko</translation>
    </message>
</context>
<context>
    <name>Process.Loading</name>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="67"/>
        <source>Loading</source>
        <translation>Nagloload</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="633"/>
        <location filename="../process/process.cpp" line="55"/>
        <source>Very high</source>
        <translation>Mangunguna</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="641"/>
        <location filename="../process/process.cpp" line="56"/>
        <source>High</source>
        <translation>Mataas</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="649"/>
        <location filename="../process/process.cpp" line="57"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="657"/>
        <location filename="../process/process.cpp" line="58"/>
        <source>Low</source>
        <translation>Mababa</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="665"/>
        <location filename="../process/process.cpp" line="59"/>
        <source>Very low</source>
        <translation>Mangunguna</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="673"/>
        <location filename="../process/process.cpp" line="60"/>
        <source>Custom</source>
        <translation>Pang-ibigay</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="61"/>
        <source>Invalid</source>
        <translation>Balewalay</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="199"/>
        <source>PID: %1, Error: [%2] %3</source>
        <translation>PID: %1, Error: [%2] %3</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="156"/>
        <location filename="../process/process_db.cpp" line="196"/>
        <source>Failed to change process priority</source>
        <translation>Nagkabigo ang pagbabago ng prioridad ng proseso</translation>
    </message>
</context>
<context>
    <name>Process.Show.Mode</name>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="61"/>
        <source>Applications</source>
        <translation>Aplikasyon</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="63"/>
        <source>My processes</source>
        <translation>Aking mga proseso</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="65"/>
        <source>All processes</source>
        <translation>Lahat ng mga proseso</translation>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <location filename="../process/process_db.cpp" line="267"/>
        <source>Failed to pause process</source>
        <translation>Nagkabigo ang pag-iilaw ng proseso</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="270"/>
        <source>Failed to resume process</source>
        <translation>Nagkabigo ang pagbawi ng proseso</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="273"/>
        <source>Failed to kill process</source>
        <translation>Nagkabigo ang pag-ibigay ng proseso</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="276"/>
        <source>Unknown error</source>
        <translation>Di kilala ang error</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="337"/>
        <source>Failed in sending signal to process</source>
        <translation>Nagkabigo ang pagpapadala ng signal sa proseso</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="264"/>
        <source>Failed to end process</source>
        <translation>Nagkabigo ang pagtapos ng proseso</translation>
    </message>
</context>
<context>
    <name>Process.Summary</name>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="58"/>
        <source>(%1 applications and %2 processes are running)</source>
        <translation>(%1 aplikasyon at %2 proseso ay nagloload)</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <location filename="../model/process_table_model.cpp" line="269"/>
        <source>No response</source>
        <translation>Walang tugon</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.cpp" line="275"/>
        <source>Suspend</source>
        <translation>I-suspend</translation>
    </message>
    <message>
        <location filename="../process/process_name.cpp" line="90"/>
        <location filename="../process/process_name.cpp" line="99"/>
        <location filename="../process/process_name.cpp" line="104"/>
        <source>Tray</source>
        <translation>Tray</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="680"/>
        <source>View command location</source>
        <translation>Pananatili ang lokasyon ng utos</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="83"/>
        <location filename="../gui/process_table_view.cpp" line="684"/>
        <source>Properties</source>
        <translation>Mga katangian</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="66"/>
        <location filename="../gui/process_table_view.cpp" line="608"/>
        <source>End process</source>
        <translation>Tapusin ang proseso</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="78"/>
        <location filename="../gui/process_table_view.cpp" line="620"/>
        <source>Resume process</source>
        <translation>Bawiin ang proseso</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="89"/>
        <location filename="../gui/process_table_view.cpp" line="691"/>
        <source>Kill process</source>
        <translation>Ito ang proseso</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="627"/>
        <source>Change priority</source>
        <translation>Baguhin ang prioridad</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="72"/>
        <location filename="../gui/process_table_view.cpp" line="614"/>
        <source>Suspend process</source>
        <translation>Pausuhin ang proseso</translation>
    </message>
</context>
<context>
    <name>Process.Table.Custom.Priority.Dialog</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="1052"/>
        <source>Custom Priority</source>
        <translation>Mga Paboritong Paggawa</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="1085"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished">Cancel</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="1087"/>
        <source>Change</source>
        <comment>button</comment>
        <translation type="unfinished">Change</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <location filename="../model/process_table_model.h" line="16"/>
        <source>Name</source>
        <translation>Pangalan</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="18"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="22"/>
        <source>Memory</source>
        <translation>Memorya</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="32"/>
        <source>Disk write</source>
        <translation>Pagsusulat sa Disk</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="30"/>
        <source>Disk read</source>
        <translation>Pagbasa sa Disk</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="28"/>
        <source>Download</source>
        <translation>Pangalawang Pagbasa</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="26"/>
        <source>Upload</source>
        <translation>Pagsusulat</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="34"/>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="20"/>
        <source>User</source>
        <translation>Mga Gumagamit</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="36"/>
        <source>Nice</source>
        <translation>Nice</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="38"/>
        <source>Priority</source>
        <translation>Prioridad</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="23"/>
        <source>Shared memory</source>
        <translation>Kabugtang Memorya</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="24"/>
        <source>Virtual memory</source>
        <translation>Virtual Memory</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../system/cpu_set.cpp" line="426"/>
        <source>Not support</source>
        <translation>Hindi suportado</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="10"/>
        <source>Settings</source>
        <translation>Mga Pagpipilian</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="11"/>
        <source>System Protection</source>
        <translation>Sistema ng Pagproteksyon</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="12"/>
        <source>Show warnings when the usage exceeds the thresholds</source>
        <translation>Ipakita ang mga abiso kapag ang paggamit ay lumampas sa mga threshold</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="13"/>
        <source>CPU warning threshold (%)</source>
        <translation>CPU warning threshold (%)</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="14"/>
        <source>Memory warning threshold (%)</source>
        <translation>Memory warning threshold (%)</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="15"/>
        <source>Warning interval (min)</source>
        <translation>Interval ng abiso (min)</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="16"/>
        <source>Notifications</source>
        <translation>Mga Abiso</translation>
    </message>
</context>
<context>
    <name>Service.Action.Set.Startup.Mode</name>
    <message>
        <location filename="../service/service_manager.cpp" line="342"/>
        <source>Failed to set service startup type</source>
        <translation>Nagawa ang pag-iskedyul ng serbisyo</translation>
    </message>
    <message>
        <location filename="../service/service_manager.cpp" line="408"/>
        <source>Error: Failed to set service startup type due to the crashed sub process.</source>
        <translation>Error: Nagawa ang pag-iskedyul ng serbisyo dahil sa crash na sub process.</translation>
    </message>
</context>
<context>
    <name>Service.Instance.Name.Dialog</name>
    <message>
        <location filename="../gui/system_service_table_view.cpp" line="157"/>
        <location filename="../gui/system_service_table_view.cpp" line="224"/>
        <location filename="../gui/system_service_table_view.cpp" line="292"/>
        <source>Service instance name</source>
        <translation>Pangalan ng instance ng serbisyo</translation>
    </message>
    <message>
        <location filename="../gui/service_name_sub_input_dialog.cpp" line="38"/>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <location filename="../gui/service_name_sub_input_dialog.cpp" line="39"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancel</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <location filename="../common/common.cpp" line="118"/>
        <location filename="../gui/system_service_table_view.cpp" line="562"/>
        <source>Refresh</source>
        <translation>Pangalawang Paglilipat</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="103"/>
        <location filename="../gui/system_service_table_view.cpp" line="542"/>
        <source>Start</source>
        <translation>Pagsimula</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="108"/>
        <location filename="../gui/system_service_table_view.cpp" line="547"/>
        <source>Stop</source>
        <translation>Tumigil</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="113"/>
        <location filename="../gui/system_service_table_view.cpp" line="552"/>
        <source>Restart</source>
        <translation>Ibalik</translation>
    </message>
    <message>
        <location filename="../gui/system_service_table_view.cpp" line="558"/>
        <source>Auto</source>
        <translation>Awtomatiko</translation>
    </message>
    <message>
        <location filename="../gui/system_service_table_view.cpp" line="559"/>
        <source>Manual</source>
        <translation>Manwal</translation>
    </message>
    <message>
        <location filename="../gui/system_service_table_view.cpp" line="557"/>
        <source>Startup type</source>
        <translation>Uri ng Pagpapalad</translation>
    </message>
</context>
<context>
    <name>Service.Table.Header</name>
    <message>
        <location filename="../model/system_service_table_model.h" line="16"/>
        <source>Name</source>
        <translation>Pangalan</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="18"/>
        <source>Load</source>
        <translation>I-load</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="23"/>
        <source>Sub</source>
        <translation>Sub</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="30"/>
        <source>Description</source>
        <translation>Pangalawang Pahayag</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="32"/>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="27"/>
        <source>Startup Type</source>
        <translation>Uri ng Pagpapalad</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="21"/>
        <source>Start State</source>
        <translation>Kasalukuyang Estado</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="25"/>
        <source>Start Tactic</source>
        <translation>Pamamaraan ng Pagpapalad</translation>
    </message>
</context>
<context>
    <name>SystemProtectionSetting</name>
    <message>
        <location filename="../gui/dialog/systemprotectionsetting.cpp" line="132"/>
        <source>Settings</source>
        <translation>Mga Pagpipilian</translation>
    </message>
    <message>
        <location filename="../gui/dialog/systemprotectionsetting.cpp" line="165"/>
        <source>(Modifiable)</source>
        <translation>(Mga Maayos na Pagbabago)</translation>
    </message>
    <message>
        <location filename="../gui/dialog/systemprotectionsetting.cpp" line="278"/>
        <location filename="../gui/dialog/systemprotectionsetting.cpp" line="387"/>
        <source>Range: %1-%2</source>
        <translation>Ranggo: %1-%2</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <location filename="../common/common.cpp" line="59"/>
        <location filename="../gui/main_window.cpp" line="129"/>
        <source>Force end application</source>
        <translation>Mag-apply ng karahasan</translation>
    </message>
    <message>
        <location filename="../gui/main_window.cpp" line="147"/>
        <source>Expand</source>
        <translation>I-expand</translation>
    </message>
    <message>
        <location filename="../gui/main_window.cpp" line="150"/>
        <source>Compact</source>
        <translation>I-compact</translation>
    </message>
    <message>
        <location filename="../gui/main_window.cpp" line="142"/>
        <source>View</source>
        <translation>Pananood</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <location filename="../common/common.cpp" line="44"/>
        <location filename="../gui/toolbar.cpp" line="95"/>
        <source>Search</source>
        <translation>Paghahanap</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <location filename="../common/common.cpp" line="53"/>
        <location filename="../gui/main_window.cpp" line="224"/>
        <location filename="../gui/main_window.cpp" line="235"/>
        <location filename="../gui/toolbar.cpp" line="45"/>
        <source>Processes</source>
        <translation>Mga Proseso</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="98"/>
        <location filename="../gui/main_window.cpp" line="224"/>
        <location filename="../gui/main_window.cpp" line="235"/>
        <location filename="../gui/main_window.cpp" line="245"/>
        <location filename="../gui/toolbar.cpp" line="53"/>
        <source>Services</source>
        <translation>Mga Serbisyo</translation>
    </message>
    <message>
        <location filename="../gui/main_window.cpp" line="245"/>
        <location filename="../gui/toolbar.cpp" line="60"/>
        <source>Users</source>
        <translation>Mga Gumagamit</translation>
    </message>
</context>
<context>
    <name>User.Account.Operation</name>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="102"/>
        <source>Edit account information</source>
        <translation>I-edit ang impormasyon ng account</translation>
    </message>
</context>
<context>
    <name>User.Account.Type</name>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="152"/>
        <source>Administrator</source>
        <translation>Administrator</translation>
    </message>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="152"/>
        <source>Standard User</source>
        <translation>Standard User</translation>
    </message>
</context>
</TS>
